<?php

namespace Teknisa\FIN\Modules\ContaReceber\Controllers;

use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request\Row;
use Teknisa\Libs\Service\CRUD as CrudService;
use Teknisa\Libs\Util\Environment;
use Teknisa\FIN\Controllers\TeknisaCrud;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;
use Teknisa\FIN\Modules\ContaReceber\Services\AjusteContaService as AjusteContaService;

/**
 * Class AjusteContaController
 * @package Teknisa\FIN\Modules\ContaReceber\Controllers
 */
class AjusteContaController extends TeknisaCrud{

    protected $dataSourceName = 'ajctreceber_tipoajreceber';

    /**
     * @param CrudService $crudService
     * @param ParameterBag $parameterBag
     * @param Environment $environment
     * @param AjusteContaService $ajusteContaService
     */
    public function __construct(CrudService $crudService, ParameterBag $parameterBag, Environment $environment, AjusteContaService $ajusteContaService)
    {
        $this->crudService  = $crudService;
        $this->parameterBag = $parameterBag;
        $this->environment  = $environment;
        $this->ajusteContaService = $ajusteContaService;
    }

    /**
     * Deleta
     * @param Row $row
     * @param Response $response
     */
    public function deletaAjusteConta(Row $row, Response $response)
    {
        try {
            // Dados do Registro
            $rows = $row->getRow();

            // Parâmetros Iniciais
            $nrorg        = $rows['NRORG'];
            $cdfilial     = $rows['CDFILIAL'];
            $cdempresa    = $rows['CDEMPRESA'];
            $valoratual   = $rows['VRATUAREC'];
            $idajuste     = $rows['IDAJUCTREC'];
            $cdfiliemit   = $rows['CDFILIEMIT'];
            $nrlanctonf   = $rows['NRLANCTONF'];
            $cdtpctreceb  = $rows['CDTPCTRECEB'];
            $nrlanbolrec  = $rows['NRLANBOLREC'];
            $nrseqvenrec  = $rows['NRSEQVENREC'];
            $valorajuste  = $rows['VRAJUSTEREC'];
            $vrajuste     = $rows['VRAJUSTEREC'];
            $nrparcelarec = $rows['NRPARCELAREC'];
            $dtajusterec  = $rows['DTAJUSTEREC'];
            $cdclassfina  = $rows['CDCLASSFINA'];
            $idmovfluxo   = $rows['IDMOVFLUXO'];
            $cdajuctrec   = $rows['CDAJUCTREC'];
            $idstatrec    = $rows['IDSTATREC'];
            $vrentmfluxo  = $rows['VRAJUSTEREC'] * -1;

            // Salva Titulo a Receber
            $this->ajusteContaService->deletaAjusteConta(
                $nrorg, $cdfilial, $cdtpctreceb, $nrlanbolrec, $cdfiliemit, $nrparcelarec, $nrseqvenrec, $valorajuste,
                $nrlanctonf, $idajuste, $vrentmfluxo, $vrajuste, $valoratual, $dtajusterec, $cdempresa,
                $cdclassfina, $idmovfluxo, $cdajuctrec, $idstatrec
            );

            // Registra Dados
            $response->addDataSet(new DataSet('DeletaAjusteConta', ['success' => 'S']));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

} 